@@ -71,7 +71,6 @@ int main(int argc, char **argv)
 
 	static struct option long_options[] = {
 		{"hba-file", required_argument, NULL, 'a'},
-		{"clear", no_argument, NULL, 'c'},
 		{"debug", no_argument, NULL, 'd'},
 		{"config-file", required_argument, NULL, 'f'},
 		{"pcp-file", required_argument, NULL, 'F'},
@@ -330,17 +329,17 @@ static void usage(void)
 	fprintf(stderr, "  pgpool [ -f CONFIG_FILE ] [ -F PCP_CONFIG_FILE ] [ -a HBA_CONFIG_FILE ] reload\n\n");
 	fprintf(stderr, "Common options:\n");
 	fprintf(stderr, "  -a, --hba-file=HBA_CONFIG_FILE\n");
-	fprintf(stderr, "                      Sets the path to the pool_hba.conf configuration file\n");
+	fprintf(stderr, "                      Set the path to the pool_hba.conf configuration file\n");
 	fprintf(stderr, "                      (default: %s/%s)\n",DEFAULT_CONFIGDIR, HBA_CONF_FILE_NAME);
 	fprintf(stderr, "  -f, --config-file=CONFIG_FILE\n");
-	fprintf(stderr, "                      Sets the path to the pgpool.conf configuration file\n");
+	fprintf(stderr, "                      Set the path to the pgpool.conf configuration file\n");
 	fprintf(stderr, "                      (default: %s/%s)\n",DEFAULT_CONFIGDIR, POOL_CONF_FILE_NAME);
 	fprintf(stderr, "  -F, --pcp-file=PCP_CONFIG_FILE\n");
-	fprintf(stderr, "                      Sets the path to the pcp.conf configuration file\n");
+	fprintf(stderr, "                      Set the path to the pcp.conf configuration file\n");
 	fprintf(stderr, "                      (default: %s/%s)\n",DEFAULT_CONFIGDIR, PCP_PASSWD_FILE_NAME);
-	fprintf(stderr, "  -h, --help          Prints this help\n\n");
+	fprintf(stderr, "  -h, --help          Print this help\n\n");
 	fprintf(stderr, "Start options:\n");
-	fprintf(stderr, "  -C, --clear-oidmaps Clears query cache oidmaps when memqcache_method is memcached\n");
+	fprintf(stderr, "  -C, --clear-oidmaps Clear query cache oidmaps when memqcache_method is memcached\n");
 	fprintf(stderr, "                      (If shmem, discards whenever pgpool starts.)\n");
 	fprintf(stderr, "  -n, --dont-detach   Don't run in daemon mode, does not detach control tty\n");
 	fprintf(stderr, "  -x, --debug-assertions   Turns on various assertion checks, This is a debugging aid\n");
